API docs for “spamfighter.interfaces.IAttributeDomain”

# Class s.i.IAttributeDomain(Interface):

Part of spamfighter.interfaces View Source View In Hierarchy

Домент (тип атрибута).

Method | name | Получить имя атрибута.
Method | serialize | Получить сериализованное значение атрибута.
Method | deserialize | Десериализовать значение в атрибут.

def name(): (source)
Получить имя атрибута.

Returns | имя атрибута (type: `str` )

def serialize(attribute): (source)
Получить сериализованное значение атрибута.

Parameters | attribute | атрибут (type: `IAttribute` )
Returns | сериализованное значение атрибута

def deserialize(value): (source)
Десериализовать значение в атрибут.

Parameters | value | сериализованное значение
Returns | атрибут (type: `IAttribute` )